@@ -1,6 +1,6 @@
 module Remotipart
 
-  # A middleware to look for our form parameters and 
+  # A middleware to look for our form parameters and
   # encourage Rails to respond with the requested format
   class Middleware
     def initialize app
@@ -9,7 +9,12 @@ module Remotipart
 
     def call env
       # Get request params
-      params = Rack::Request.new(env).params
+      begin
+        params = Rack::Request.new(env).params
+      rescue TypeError => e
+        ::Rails.logger.warn e.message
+        ::Rails.logger.warn e.backtrace.join("\n")
+      end
 
       if params
         # This was using an iframe transport, and is therefore an XHR
@@ -19,8 +24,8 @@ module Remotipart
         end
 
         # Override the accepted format, because it isn't what we really want
-        if params['X-Http-Accept']
-          env['HTTP_ACCEPT'] = params['X-Http-Accept']
+        if params['X-HTTP-Accept']
+          env['HTTP_ACCEPT'] = params['X-HTTP-Accept']
         end
       end
 
